pub struct FeeConfig {
pub bump: u8,
pub admin: Pubkey,
pub flat_fees: Fees,
pub fee_tiers: Vec<FeeTier>,
}Fields
bump: u8admin: Pubkeyflat_fees: Feesfee_tiers: Vec<FeeTier>Trait Implementations
Sourceimpl BorshDeserialize for FeeConfigwhere
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
Fees: BorshDeserialize,
Vec<FeeTier>: BorshDeserialize,
impl BorshDeserialize for FeeConfigwhere
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
Fees: BorshDeserialize,
Vec<FeeTier>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for FeeConfig
impl CarbonDeserialize for FeeConfig
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl<'de> Deserialize<'de> for FeeConfig
impl<'de> Deserialize<'de> for FeeConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FeeConfig
impl StructuralPartialEq for FeeConfig