pub struct AdminSetCreator {
pub creator: Pubkey,
}Fields
creator: PubkeyTrait Implementations
Sourceimpl ArrangeAccounts for AdminSetCreator
impl ArrangeAccounts for AdminSetCreator
type ArrangedAccounts = AdminSetCreatorInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for AdminSetCreatorwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for AdminSetCreatorwhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for AdminSetCreator
impl CarbonDeserialize for AdminSetCreator
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for AdminSetCreator
impl Clone for AdminSetCreator
Sourcefn clone(&self) -> AdminSetCreator
fn clone(&self) -> AdminSetCreator
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminSetCreator
impl Debug for AdminSetCreator
Sourceimpl<'de> Deserialize<'de> for AdminSetCreator
impl<'de> Deserialize<'de> for AdminSetCreator
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AdminSetCreator
impl Hash for AdminSetCreator
Sourceimpl PartialEq for AdminSetCreator
impl PartialEq for AdminSetCreator
Sourceimpl Serialize for AdminSetCreator
impl Serialize for AdminSetCreator
impl Eq for AdminSetCreator
impl StructuralPartialEq for AdminSetCreator