pub struct AdminSetCreatorEvent {
pub timestamp: i64,
pub admin_set_creator_authority: Pubkey,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub old_creator: Pubkey,
pub new_creator: Pubkey,
}Fields
timestamp: i64mint: Pubkeybonding_curve: Pubkeyold_creator: Pubkeynew_creator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for AdminSetCreatorEvent
impl BorshDeserialize for AdminSetCreatorEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for AdminSetCreatorEvent
impl CarbonDeserialize for AdminSetCreatorEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for AdminSetCreatorEvent
impl Clone for AdminSetCreatorEvent
Sourcefn clone(&self) -> AdminSetCreatorEvent
fn clone(&self) -> AdminSetCreatorEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminSetCreatorEvent
impl Debug for AdminSetCreatorEvent
Sourceimpl<'de> Deserialize<'de> for AdminSetCreatorEvent
impl<'de> Deserialize<'de> for AdminSetCreatorEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AdminSetCreatorEvent
impl Hash for AdminSetCreatorEvent
Sourceimpl PartialEq for AdminSetCreatorEvent
impl PartialEq for AdminSetCreatorEvent
Sourceimpl Serialize for AdminSetCreatorEvent
impl Serialize for AdminSetCreatorEvent
impl Eq for AdminSetCreatorEvent
impl StructuralPartialEq for AdminSetCreatorEvent