pub struct AdminUpdateTokenIncentives {
pub start_time: i64,
pub end_time: i64,
pub seconds_in_a_day: i64,
pub day_number: u64,
pub pump_token_supply_per_day: u64,
}Fields
start_time: i64end_time: i64seconds_in_a_day: i64day_number: u64pump_token_supply_per_day: u64Trait Implementations
Sourceimpl ArrangeAccounts for AdminUpdateTokenIncentives
impl ArrangeAccounts for AdminUpdateTokenIncentives
type ArrangedAccounts = AdminUpdateTokenIncentivesInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for AdminUpdateTokenIncentives
impl BorshDeserialize for AdminUpdateTokenIncentives
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for AdminUpdateTokenIncentives
impl CarbonDeserialize for AdminUpdateTokenIncentives
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for AdminUpdateTokenIncentives
impl Clone for AdminUpdateTokenIncentives
Sourcefn clone(&self) -> AdminUpdateTokenIncentives
fn clone(&self) -> AdminUpdateTokenIncentives
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminUpdateTokenIncentives
impl Debug for AdminUpdateTokenIncentives
Sourceimpl<'de> Deserialize<'de> for AdminUpdateTokenIncentives
impl<'de> Deserialize<'de> for AdminUpdateTokenIncentives
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AdminUpdateTokenIncentives
impl Hash for AdminUpdateTokenIncentives
impl Eq for AdminUpdateTokenIncentives
impl StructuralPartialEq for AdminUpdateTokenIncentives