pub struct AdminUpdateTokenIncentivesEvent {
pub start_time: i64,
pub end_time: i64,
pub day_number: u64,
pub token_supply_per_day: u64,
pub mint: Pubkey,
pub seconds_in_a_day: i64,
pub timestamp: i64,
}Fields
start_time: i64end_time: i64day_number: u64token_supply_per_day: u64mint: Pubkeyseconds_in_a_day: i64timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for AdminUpdateTokenIncentivesEvent
impl BorshDeserialize for AdminUpdateTokenIncentivesEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for AdminUpdateTokenIncentivesEvent
impl CarbonDeserialize for AdminUpdateTokenIncentivesEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for AdminUpdateTokenIncentivesEvent
impl Clone for AdminUpdateTokenIncentivesEvent
Sourcefn clone(&self) -> AdminUpdateTokenIncentivesEvent
fn clone(&self) -> AdminUpdateTokenIncentivesEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AdminUpdateTokenIncentivesEvent
impl<'de> Deserialize<'de> for AdminUpdateTokenIncentivesEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AdminUpdateTokenIncentivesEvent
impl PartialEq for AdminUpdateTokenIncentivesEvent
Sourcefn eq(&self, other: &AdminUpdateTokenIncentivesEvent) -> bool
fn eq(&self, other: &AdminUpdateTokenIncentivesEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AdminUpdateTokenIncentivesEvent
impl StructuralPartialEq for AdminUpdateTokenIncentivesEvent