pub struct CompleteEvent {
pub user: Pubkey,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub timestamp: i64,
}Fields
user: Pubkeymint: Pubkeybonding_curve: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for CompleteEvent
impl BorshDeserialize for CompleteEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for CompleteEvent
impl CarbonDeserialize for CompleteEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for CompleteEvent
impl Clone for CompleteEvent
Sourcefn clone(&self) -> CompleteEvent
fn clone(&self) -> CompleteEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompleteEvent
impl Debug for CompleteEvent
Sourceimpl<'de> Deserialize<'de> for CompleteEvent
impl<'de> Deserialize<'de> for CompleteEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CompleteEvent
impl Hash for CompleteEvent
Sourceimpl PartialEq for CompleteEvent
impl PartialEq for CompleteEvent
Sourceimpl Serialize for CompleteEvent
impl Serialize for CompleteEvent
impl Eq for CompleteEvent
impl StructuralPartialEq for CompleteEvent