pub struct CreateEvent {
pub name: String,
pub symbol: String,
pub uri: String,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub user: Pubkey,
pub creator: Pubkey,
pub timestamp: i64,
pub virtual_token_reserves: u64,
pub virtual_sol_reserves: u64,
pub real_token_reserves: u64,
pub token_total_supply: u64,
}Fields
name: Stringsymbol: Stringuri: Stringmint: Pubkeybonding_curve: Pubkeyuser: Pubkeycreator: Pubkeytimestamp: i64virtual_token_reserves: u64virtual_sol_reserves: u64real_token_reserves: u64token_total_supply: u64Trait Implementations
Sourceimpl BorshDeserialize for CreateEventwhere
String: BorshDeserialize,
Pubkey: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
impl BorshDeserialize for CreateEventwhere
String: BorshDeserialize,
Pubkey: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for CreateEvent
impl CarbonDeserialize for CreateEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for CreateEvent
impl Clone for CreateEvent
Sourcefn clone(&self) -> CreateEvent
fn clone(&self) -> CreateEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateEvent
impl Debug for CreateEvent
Sourceimpl<'de> Deserialize<'de> for CreateEvent
impl<'de> Deserialize<'de> for CreateEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CreateEvent
impl Hash for CreateEvent
Sourceimpl PartialEq for CreateEvent
impl PartialEq for CreateEvent
Sourceimpl Serialize for CreateEvent
impl Serialize for CreateEvent
impl Eq for CreateEvent
impl StructuralPartialEq for CreateEvent