pub struct ExtendAccount {}Trait Implementations
Sourceimpl ArrangeAccounts for ExtendAccount
impl ArrangeAccounts for ExtendAccount
type ArrangedAccounts = ExtendAccountInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for ExtendAccount
impl BorshDeserialize for ExtendAccount
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for ExtendAccount
impl CarbonDeserialize for ExtendAccount
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for ExtendAccount
impl Clone for ExtendAccount
Sourcefn clone(&self) -> ExtendAccount
fn clone(&self) -> ExtendAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtendAccount
impl Debug for ExtendAccount
Sourceimpl<'de> Deserialize<'de> for ExtendAccount
impl<'de> Deserialize<'de> for ExtendAccount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ExtendAccount
impl Hash for ExtendAccount
Sourceimpl PartialEq for ExtendAccount
impl PartialEq for ExtendAccount
Sourceimpl Serialize for ExtendAccount
impl Serialize for ExtendAccount
impl Eq for ExtendAccount
impl StructuralPartialEq for ExtendAccount