pub struct ExtendAccountEvent {
pub account: Pubkey,
pub user: Pubkey,
pub current_size: u64,
pub new_size: u64,
pub timestamp: i64,
}Fields
account: Pubkeyuser: Pubkeycurrent_size: u64new_size: u64timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for ExtendAccountEvent
impl BorshDeserialize for ExtendAccountEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for ExtendAccountEvent
impl CarbonDeserialize for ExtendAccountEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for ExtendAccountEvent
impl Clone for ExtendAccountEvent
Sourcefn clone(&self) -> ExtendAccountEvent
fn clone(&self) -> ExtendAccountEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtendAccountEvent
impl Debug for ExtendAccountEvent
Sourceimpl<'de> Deserialize<'de> for ExtendAccountEvent
impl<'de> Deserialize<'de> for ExtendAccountEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ExtendAccountEvent
impl Hash for ExtendAccountEvent
Sourceimpl PartialEq for ExtendAccountEvent
impl PartialEq for ExtendAccountEvent
Sourceimpl Serialize for ExtendAccountEvent
impl Serialize for ExtendAccountEvent
impl Eq for ExtendAccountEvent
impl StructuralPartialEq for ExtendAccountEvent