pub struct SetCreator {
pub creator: Pubkey,
}Fields
creator: PubkeyTrait Implementations
Sourceimpl ArrangeAccounts for SetCreator
impl ArrangeAccounts for SetCreator
type ArrangedAccounts = SetCreatorInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for SetCreatorwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for SetCreatorwhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for SetCreator
impl CarbonDeserialize for SetCreator
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for SetCreator
impl Clone for SetCreator
Sourcefn clone(&self) -> SetCreator
fn clone(&self) -> SetCreator
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetCreator
impl Debug for SetCreator
Sourceimpl<'de> Deserialize<'de> for SetCreator
impl<'de> Deserialize<'de> for SetCreator
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for SetCreator
impl Hash for SetCreator
Sourceimpl PartialEq for SetCreator
impl PartialEq for SetCreator
Sourceimpl Serialize for SetCreator
impl Serialize for SetCreator
impl Eq for SetCreator
impl StructuralPartialEq for SetCreator