pub struct SetCreatorEvent {
pub timestamp: i64,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub creator: Pubkey,
}Fields
timestamp: i64mint: Pubkeybonding_curve: Pubkeycreator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for SetCreatorEvent
impl BorshDeserialize for SetCreatorEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for SetCreatorEvent
impl CarbonDeserialize for SetCreatorEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for SetCreatorEvent
impl Clone for SetCreatorEvent
Sourcefn clone(&self) -> SetCreatorEvent
fn clone(&self) -> SetCreatorEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetCreatorEvent
impl Debug for SetCreatorEvent
Sourceimpl<'de> Deserialize<'de> for SetCreatorEvent
impl<'de> Deserialize<'de> for SetCreatorEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for SetCreatorEvent
impl Hash for SetCreatorEvent
Sourceimpl PartialEq for SetCreatorEvent
impl PartialEq for SetCreatorEvent
Sourceimpl Serialize for SetCreatorEvent
impl Serialize for SetCreatorEvent
impl Eq for SetCreatorEvent
impl StructuralPartialEq for SetCreatorEvent