pub struct SetParams {
pub fee_recipient: Pubkey,
pub initial_virtual_token_reserves: u64,
pub initial_virtual_sol_reserves: u64,
pub initial_real_token_reserves: u64,
pub token_total_supply: u64,
pub fee_basis_points: u64,
pub withdraw_authority: Pubkey,
}Fields
fee_recipient: Pubkeyinitial_virtual_token_reserves: u64initial_virtual_sol_reserves: u64initial_real_token_reserves: u64token_total_supply: u64fee_basis_points: u64Trait Implementations
Sourceimpl ArrangeAccounts for SetParams
impl ArrangeAccounts for SetParams
type ArrangedAccounts = SetParamsInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for SetParams
impl BorshDeserialize for SetParams
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for SetParams
impl CarbonDeserialize for SetParams
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl<'de> Deserialize<'de> for SetParams
impl<'de> Deserialize<'de> for SetParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SetParams
impl StructuralPartialEq for SetParams