pub struct SetParamsEvent {
pub fee_recipient: Pubkey,
pub initial_virtual_token_reserves: u64,
pub initial_virtual_sol_reserves: u64,
pub initial_real_token_reserves: u64,
pub token_total_supply: u64,
pub fee_basis_points: u64,
}Fields
fee_recipient: Pubkeyinitial_virtual_token_reserves: u64initial_virtual_sol_reserves: u64initial_real_token_reserves: u64token_total_supply: u64fee_basis_points: u64Trait Implementations
sourceimpl BorshDeserialize for SetParamsEvent
impl BorshDeserialize for SetParamsEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl CarbonDeserialize for SetParamsEvent
impl CarbonDeserialize for SetParamsEvent
fn deserialize(data: &[u8]) -> Option<Self>
sourceimpl Clone for SetParamsEvent
impl Clone for SetParamsEvent
sourcefn clone(&self) -> SetParamsEvent
fn clone(&self) -> SetParamsEvent
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SetParamsEvent
impl Debug for SetParamsEvent
sourceimpl<'de> Deserialize<'de> for SetParamsEvent
impl<'de> Deserialize<'de> for SetParamsEvent
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for SetParamsEvent
impl Hash for SetParamsEvent
sourceimpl PartialEq for SetParamsEvent
impl PartialEq for SetParamsEvent
sourceimpl Serialize for SetParamsEvent
impl Serialize for SetParamsEvent
impl Eq for SetParamsEvent
impl StructuralPartialEq for SetParamsEvent